/***********************************************************************
 *
 * Copyright (C) 2008 Graeme Gott <graeme@gottcode.org>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#ifndef WINDOW_H
#define WINDOW_H

#include <QDateTime>
#include <QMap>
#include <QWidget>
class QAction;
class QComboBox;
class QLabel;
class QModelIndex;
class QPushButton;
class QTimer;
class QTreeView;
class DataModel;

class Window : public QWidget {
	Q_OBJECT
public:
	Window(QWidget* parent = 0);

protected:
	virtual void closeEvent(QCloseEvent* event);

private slots:
	void start();
	void stop();
	void cancel();
	void updateDisplay();
	void autoSave();
	void addProject();
	void projectActivated(const QString& project);
	void sessionPressed(const QModelIndex& index);
	void sessionsInserted(const QModelIndex& parent, int start, int end);
	void addSession();
	void editSession();
	void removeSession();
	void save();

private:
	void finish();

private:
	QComboBox* m_projects;
	QLabel* m_display;
	QTimer* m_timer;
	QTimer* m_auto_timer;
	QDateTime m_start_time;
	QPushButton* m_start;
	QPushButton* m_stop;
	QPushButton* m_cancel;
	QTreeView* m_details;
	DataModel* m_active_model;
	QMap<QString, DataModel*> m_models;

	QAction* m_edit_action;
	QAction* m_remove_action;
};

#endif
